@@ -2,13 +2,11 @@
 #' @importFrom dplyr one_of ungroup slice bind_cols pull sample_n desc anti_join
 #' @importFrom dplyr distinct arrange rename mutate_if starts_with inner_join
 #' @importFrom dplyr last
-#' @importFrom tibble tibble lst is_tibble as_tibble
 #' @importFrom purrr map_int
 #' @importFrom rlang call2 ns_env is_quosure is_quosures quo_get_expr call_name
 #' @importFrom rlang is_false eval_tidy expr sym syms env_get is_function :=
 #' @importFrom rlang is_missing %||%
 #' @importFrom glue glue glue_collapse
-#' @importFrom utils globalVariables capture.output packageVersion object.size
 #' @importFrom dials parameters_constr is_unknown encode_unit
 #' @importFrom stats sd qt qnorm dnorm pnorm predict model.matrix setNames
 #' @importFrom stats model.matrix model.response model.frame update
@@ -22,6 +20,8 @@
 #' @importFrom cli cli_alert_danger cli_alert_info cli_alert_warning
 #' @importFrom cli cli_alert_success cli_alert
 #' @importFrom foreach foreach getDoParName %dopar%
+#' @importFrom tibble obj_sum size_sum
+
 
 # ------------------------------------------------------------------------------
 # Only a small number of functions in workflows.
@@ -41,13 +41,13 @@ utils::globalVariables(
     ".extracts", ".metrics", "value", ".notes", ".loss", ".bound",
     ".column", ".totals", ".value", "direction", ".config", "Freq", "Prediction",
     "Truth", ".seed", ".order", ".iter_model", ".iter_preprocessor",
-    ".iter_config", ".msg_model", "# resamples")
+    ".iter_config", ".msg_model", "# resamples", "seed")
   )
 
 # ------------------------------------------------------------------------------
 
 tidyr_new_interface <- function() {
-  packageVersion("tidyr") > "0.8.99"
+  utils::packageVersion("tidyr") > "0.8.99"
 }
 
 # ------------------------------------------------------------------------------
