@@ -83,11 +83,11 @@ mod_type <- function(.mod) class(.mod)[class(.mod) != "model_spec"][1]
 #' @export
 #' @rdname tunable
 tunable.workflow <- function(x, ...) {
-  model <- workflows::pull_workflow_spec(x)
+  model <- extract_spec_parsnip(x)
   param_data <- tunable(model)
 
   if (has_preprocessor_recipe(x)) {
-    recipe <- workflows::pull_workflow_preprocessor(x)
+    recipe <- extract_preprocessor(x)
     recipe_param_data <- tunable(recipe)
 
     param_data <- dplyr::bind_rows(param_data, recipe_param_data)
