@@ -28,7 +28,7 @@
 #' library(recipes)
 #'
 #' recipe(mpg ~ ., data = mtcars) %>%
-#'   step_knnimpute(all_predictors(), neighbors = tune()) %>%
+#'   step_impute_knn(all_predictors(), neighbors = tune()) %>%
 #'   step_pca(all_predictors(), num_comp = tune()) %>%
 #'   tune_args()
 #'
@@ -159,12 +159,12 @@ tune_args.check <- tune_args.step
 #' @export
 #' @rdname tune_args
 tune_args.workflow <- function(object, ...) {
-  model <- workflows::pull_workflow_spec(object)
+  model <- extract_spec_parsnip(object)
 
   param_data <- tune_args(model)
 
   if (has_preprocessor_recipe(object)) {
-    recipe <- workflows::pull_workflow_preprocessor(object)
+    recipe <- extract_preprocessor(object)
     recipe_param_data <- tune_args(recipe)
     param_data <- dplyr::bind_rows(param_data, recipe_param_data)
   }
