@@ -7,7 +7,7 @@ source(test_path("../helper-objects.R"))
 # ------------------------------------------------------------------------------
 
 test_that('boosted tree grid reduction - xgboost', {
-  
+
 
   mod <- boost_tree() %>% set_engine("xgboost")
 
@@ -56,7 +56,7 @@ test_that('boosted tree grid reduction - xgboost', {
   expect_equal(no_sub_smol$trees, rep(1, 2))
   expect_equal(no_sub_smol$min_n, 1:2)
   for (i in 1:nrow(no_sub_smol)) {
-    expect_null(no_sub_smol$.submodels[[i]])
+    expect_length(no_sub_smol$.submodels[[i]], 0)
   }
 
   # different id names
@@ -92,7 +92,7 @@ test_that('boosted tree grid reduction - xgboost', {
 # ------------------------------------------------------------------------------
 
 test_that('boosted tree grid reduction - C5.0', {
-  
+
   mod <- boost_tree() %>% set_engine("C5.0")
 
   # A typical grid
@@ -140,7 +140,7 @@ test_that('boosted tree grid reduction - C5.0', {
   expect_equal(no_sub_smol$trees, rep(1, 2))
   expect_equal(no_sub_smol$min_n, 1:2)
   for (i in 1:nrow(no_sub_smol)) {
-    expect_null(no_sub_smol$.submodels[[i]])
+    expect_length(no_sub_smol$.submodels[[i]], 0)
   }
 
   # different id names
@@ -176,7 +176,7 @@ test_that('boosted tree grid reduction - C5.0', {
 
 
 test_that('linear regression grid reduction - glmnet', {
-  
+
   # glmnet depends on >= 3.6.0 so we only test locally
   skip_if_not_installed("glmnet")
 
@@ -232,7 +232,7 @@ test_that('linear regression grid reduction - glmnet', {
   expect_equal(no_sub_smol$penalty, 1:5)
   expect_equal(no_sub_smol$mixture, (1:5)/5)
   for (i in 1:nrow(no_sub_smol)) {
-    expect_null(no_sub_smol$.submodels[[i]])
+    expect_length(no_sub_smol$.submodels[[i]], 0)
   }
 
   # different id names
@@ -268,7 +268,7 @@ test_that('linear regression grid reduction - glmnet', {
 # ------------------------------------------------------------------------------
 
 test_that('logistic regression grid reduction - glmnet', {
-  
+
   # glmnet depends on >= 3.6.0 so we only test locally
   skip_if_not_installed("glmnet")
 
@@ -306,7 +306,7 @@ test_that('logistic regression grid reduction - glmnet', {
     expect_equal(reg_grid_extra_smol$.submodels[[i]], list(penalty = 1:2))
   }
 
-  # Penaly not specified
+  # Penalty not specified
   expect_error(min_grid(mod, data.frame(mixture = 1:3)),
                "At least one penalty value is required for glmnet")
 
@@ -324,7 +324,7 @@ test_that('logistic regression grid reduction - glmnet', {
   expect_equal(no_sub_smol$penalty, 1:5)
   expect_equal(no_sub_smol$mixture, (1:5)/5)
   for (i in 1:nrow(no_sub_smol)) {
-    expect_null(no_sub_smol$.submodels[[i]])
+    expect_length(no_sub_smol$.submodels[[i]], 0)
   }
 
 
@@ -359,7 +359,7 @@ test_that('logistic regression grid reduction - glmnet', {
 
 # more of a negative control test
 test_that('logistic regression grid reduction - spark', {
-  
+
   reg_grid <- expand.grid(penalty = 1:3, mixture = (1:5)/5)
   reg_grid_smol <- min_grid(logistic_reg() %>% set_engine("spark"), reg_grid)
 
@@ -373,7 +373,7 @@ test_that('logistic regression grid reduction - spark', {
 # ------------------------------------------------------------------------------
 
 test_that('MARS grid reduction - earth', {
-  
+
   mod <- mars() %>% set_engine("earth")
 
   # A typical grid
@@ -421,7 +421,7 @@ test_that('MARS grid reduction - earth', {
   expect_equal(no_sub_smol$num_terms, rep(1, 2))
   expect_equal(no_sub_smol$prod_degree, 1:2)
   for (i in 1:nrow(no_sub_smol)) {
-    expect_null(no_sub_smol$.submodels[[i]])
+    expect_length(no_sub_smol$.submodels[[i]], 0)
   }
 
 
@@ -457,7 +457,7 @@ test_that('MARS grid reduction - earth', {
 # ------------------------------------------------------------------------------
 
 test_that('multinomial regression grid reduction - glmnet', {
-  
+
   # glmnet depends on >= 3.6.0 so we only test locally
   skip_if_not_installed("glmnet")
 
@@ -513,7 +513,7 @@ test_that('multinomial regression grid reduction - glmnet', {
   expect_equal(no_sub_smol$penalty, 1:5)
   expect_equal(no_sub_smol$mixture, (1:5)/5)
   for (i in 1:nrow(no_sub_smol)) {
-    expect_null(no_sub_smol$.submodels[[i]])
+    expect_length(no_sub_smol$.submodels[[i]], 0)
   }
 
   # different id names
@@ -549,7 +549,7 @@ test_that('multinomial regression grid reduction - glmnet', {
 
 
 test_that('nearest neighbors grid reduction - kknn', {
-  
+
   mod <- nearest_neighbor() %>% set_engine("kknn")
 
   # A typical grid
@@ -598,7 +598,7 @@ test_that('nearest neighbors grid reduction - kknn', {
   expect_equal(no_sub_smol$neighbors, rep(1, 2))
   expect_equal(no_sub_smol$dist_power, 1:2)
   for (i in 1:nrow(no_sub_smol)) {
-    expect_null(no_sub_smol$.submodels[[i]])
+    expect_length(no_sub_smol$.submodels[[i]], 0)
   }
 
 
