@@ -8,7 +8,7 @@ load(test_path("test_objects.RData"))
 # ------------------------------------------------------------------------------
 
 test_that('model package lookup', {
-  mod_obj <- workflows::pull_workflow_spec(chi_wflow)
+  mod_obj <- extract_spec_parsnip(chi_wflow)
   expect_equal(tune::required_pkgs(mod_obj, FALSE), "glmnet")
 })
 
